import { ref, onMounted, onUnmounted, computed, createVNode, defineComponent, openBlock, createElementBlock, createElementVNode, watchEffect, resolveComponent, createBlock, Transition, withCtx, normalizeClass, normalizeStyle, createCommentVNode, toDisplayString, renderSlot, render } from "vue";
const SWIPE_ACTIVE_DIFF = 200;
const TOAST_GAP = 12;
const DEFAULT_OPTIONS = {
  type: "default",
  timeout: 5e3,
  showCloseButton: true,
  position: "top-right",
  transition: "bounce",
  hideProgressBar: false,
  swipeClose: true
};
var ToastContentType = /* @__PURE__ */ ((ToastContentType2) => {
  ToastContentType2[ToastContentType2["TITLE_ONLY"] = 0] = "TITLE_ONLY";
  ToastContentType2[ToastContentType2["TITLE_DESCRIPTION"] = 1] = "TITLE_DESCRIPTION";
  ToastContentType2[ToastContentType2["COMPONENT"] = 2] = "COMPONENT";
  ToastContentType2[ToastContentType2["VNODE"] = 3] = "VNODE";
  return ToastContentType2;
})(ToastContentType || {});
const useTimer = (callback, delay) => {
  const timerId = ref();
  const startTime = ref(0);
  const remainingTime = ref(delay);
  const intervalId = ref();
  const progress = ref(100);
  const stop = () => {
    clearInterval(intervalId.value);
    clearTimeout(timerId.value);
    remainingTime.value -= Date.now() - startTime.value;
  };
  const start = () => {
    startTime.value = Date.now();
    clearTimeout(timerId.value);
    intervalId.value = setInterval(() => {
      progress.value--;
    }, delay / 100 - 5);
    timerId.value = setTimeout(callback, remainingTime.value);
  };
  const clear = () => {
    clearInterval(intervalId.value);
    clearTimeout(timerId.value);
  };
  onMounted(() => {
    if (delay <= 0)
      return;
  });
  onUnmounted(() => {
    clear();
  });
  return { start, stop, clear, progress };
};
const TRANSITION_MAP = {
  "top-left": {
    bounce: "mosha__bounceInLeft",
    zoom: "mosha__zoomIn",
    slide: "mosha__slideInLeft"
  },
  "top-right": {
    bounce: "mosha__bounceInRight",
    zoom: "mosha__zoomIn",
    slide: "mosha__slideInRight"
  },
  "top-center": {
    bounce: "mosha__bounceInDown",
    zoom: "mosha__zoomIn",
    slide: "mosha__slideInDown"
  },
  "bottom-center": {
    bounce: "mosha__bounceInUp",
    zoom: "mosha__zoomIn",
    slide: "mosha__slideInUp"
  },
  "bottom-right": {
    bounce: "mosha__bounceInRight",
    zoom: "mosha__zoomIn",
    slide: "mosha__slideInRight"
  },
  "bottom-left": {
    bounce: "mosha__bounceInLeft",
    zoom: "mosha__zoomIn",
    slide: "mosha__slideInLeft"
  }
};
const useTransitionType = (position, transition, swiped) => {
  const transitionType = computed(() => {
    if (swiped.value > SWIPE_ACTIVE_DIFF) {
      return "mosha__fadeOutLeft";
    } else if (swiped.value < -SWIPE_ACTIVE_DIFF) {
      return "mosha__fadeOutRight";
    } else {
      return TRANSITION_MAP[position][transition];
    }
  });
  return { transitionType };
};
const useCustomStyle = (position, offset, bgColor) => {
  const customStyle = computed(() => {
    switch (position) {
      case "top-left":
        return {
          left: "0",
          top: `${offset}px`
        };
      case "bottom-left":
        return {
          left: "0",
          bottom: `${offset}px`
        };
      case "bottom-right":
        return {
          right: "0",
          bottom: `${offset}px`
        };
      case "top-center":
        return {
          top: `${offset}px`,
          left: "0",
          right: "0",
          marginRight: "auto",
          marginLeft: "auto"
        };
      case "bottom-center":
        return {
          bottom: `${offset}px`,
          left: "0",
          right: "0",
          marginRight: "auto",
          marginLeft: "auto"
        };
      default:
        return {
          right: "0",
          top: `${offset}px`
        };
    }
  });
  if (bgColor.length > 0) {
    customStyle.value.backgroundColor = bgColor;
  }
  return { customStyle };
};
const withProps = (component, props) => {
  return createVNode(component, props);
};
const debounce = (fn, delay = 300) => {
  let timeoutId = void 0;
  return (...args) => {
    if (timeoutId) {
      clearTimeout(timeoutId);
      timeoutId = void 0;
    }
    timeoutId = setTimeout(() => fn(...args), delay);
  };
};
const useScreenSize = () => {
  const width = ref(-1);
  const height = ref(-1);
  const resizeHandler = (e) => {
    if (e !== null && e.currentTarget !== null) {
      width.value = e.currentTarget.innerWidth;
      height.value = e.currentTarget.innerHeight;
    }
  };
  onMounted(() => {
    if (window.innerWidth > 0) {
      width.value = window.innerWidth;
      height.value = window.innerHeight;
    }
    window.addEventListener("resize", debounce(resizeHandler));
  });
  onUnmounted(() => {
    window.removeEventListener("resize", debounce(resizeHandler));
  });
  return {
    width,
    height
  };
};
const useSwipe = (position, onCloseHandler, swipeClose) => {
  const swipeStart = ref();
  const swipedDiff = ref(void 0);
  const swipeStyle = ref();
  const isMouseEvent = (event) => event instanceof MouseEvent;
  const swipeHandler = (event) => {
    if (swipeClose === false || !swipeStart.value)
      return;
    if (isMouseEvent(event)) {
      swipedDiff.value = swipeStart.value.clientX - event.clientX;
    } else {
      swipedDiff.value = swipeStart.value.touches[0].clientX - event.touches[0].clientX;
    }
    swipeStyle.value = {
      ...swipeStyle.value,
      transition: "none"
    };
    if (position.endsWith("left")) {
      swipeStyle.value.left = `${-swipedDiff.value}px !important`;
    } else if (position.endsWith("right")) {
      swipeStyle.value.right = `${swipedDiff.value}px !important`;
    } else {
      if (swipedDiff.value > 0) {
        swipeStyle.value.left = `${-swipedDiff.value}px !important`;
      } else {
        swipeStyle.value.right = `${swipedDiff.value}px !important`;
      }
    }
    if (Math.abs(swipedDiff.value) > SWIPE_ACTIVE_DIFF) {
      onCloseHandler();
    }
  };
  const moveEndHandler = (move) => {
    const resetLeft = {
      transition: "left .3s ease-out",
      left: 0
    };
    const resetRight = {
      transition: "right .3s ease-out",
      right: 0
    };
    const resetCenter = {
      transition: "all .3s ease-out",
      left: 0,
      right: 0
    };
    if (position.endsWith("left")) {
      swipeStyle.value = {
        ...swipeStyle.value,
        ...resetLeft
      };
    } else if (position.endsWith("right")) {
      swipeStyle.value = {
        ...swipeStyle.value,
        ...resetRight
      };
    } else {
      swipeStyle.value = {
        ...swipeStyle.value,
        ...resetCenter
      };
    }
    swipeStart.value = void 0;
    swipedDiff.value = void 0;
    removeEventListener(move, swipeHandler);
  };
  const startSwipeHandler = (event) => {
    if (swipeClose === false)
      return;
    swipeStart.value = event;
    const move = isMouseEvent(event) ? "mousemove" : "touchmove";
    const moveEnd = isMouseEvent(event) ? "mouseup" : "touchend";
    addEventListener(move, swipeHandler);
    addEventListener(moveEnd, () => moveEndHandler(move));
  };
  const cleanUpMove = (move) => {
    if (swipeClose === false)
      return;
    if (swipeStart.value)
      swipeStart.value = void 0;
    if (swipedDiff.value)
      swipedDiff.value = void 0;
    removeEventListener(move, swipeHandler);
  };
  onUnmounted(() => {
    if (swipeClose === false)
      return;
    cleanUpMove("mousemove");
    cleanUpMove("touchmove");
  });
  return {
    swipedDiff,
    swipeStart,
    swipeStyle,
    swipeHandler,
    startSwipeHandler,
    cleanUpMove
  };
};
var _export_sfc = (sfc, props) => {
  const target = sfc.__vccOpts || sfc;
  for (const [key, val] of props) {
    target[key] = val;
  }
  return target;
};
const _sfc_main$1 = defineComponent({
  props: {
    type: {
      type: String,
      default: "default"
    }
  }
});
const _hoisted_1$1 = { class: "mosha__icon" };
const _hoisted_2$1 = {
  key: 0,
  xmlns: "http://www.w3.org/2000/svg",
  height: "32px",
  viewBox: "0 0 24 24",
  width: "32px",
  fill: "#ffffff"
};
const _hoisted_3$1 = /* @__PURE__ */ createElementVNode("path", { d: "M4.47 21h15.06c1.54 0 2.5-1.67 1.73-3L13.73 4.99c-.77-1.33-2.69-1.33-3.46 0L2.74 18c-.77 1.33.19 3 1.73 3zM12 14c-.55 0-1-.45-1-1v-2c0-.55.45-1 1-1s1 .45 1 1v2c0 .55-.45 1-1 1zm1 4h-2v-2h2v2z" }, null, -1);
const _hoisted_4$1 = [
  _hoisted_3$1
];
const _hoisted_5$1 = {
  key: 1,
  xmlns: "http://www.w3.org/2000/svg",
  height: "32px",
  viewBox: "0 0 24 24",
  width: "32px",
  fill: "#ffffff"
};
const _hoisted_6$1 = /* @__PURE__ */ createElementVNode("path", { d: "M12 2C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm0 11c-.55 0-1-.45-1-1V8c0-.55.45-1 1-1s1 .45 1 1v4c0 .55-.45 1-1 1zm1 4h-2v-2h2v2z" }, null, -1);
const _hoisted_7 = [
  _hoisted_6$1
];
const _hoisted_8 = {
  key: 2,
  xmlns: "http://www.w3.org/2000/svg",
  height: "32px",
  viewBox: "0 0 24 24",
  width: "32px",
  fill: "#ffffff"
};
const _hoisted_9 = /* @__PURE__ */ createElementVNode("path", {
  d: "M0 0h24v24H0V0z",
  fill: "none"
}, null, -1);
const _hoisted_10 = /* @__PURE__ */ createElementVNode("path", { d: "M12 2C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zM9.29 16.29L5.7 12.7c-.39-.39-.39-1.02 0-1.41.39-.39 1.02-.39 1.41 0L10 14.17l6.88-6.88c.39-.39 1.02-.39 1.41 0 .39.39.39 1.02 0 1.41l-7.59 7.59c-.38.39-1.02.39-1.41 0z" }, null, -1);
const _hoisted_11 = [
  _hoisted_9,
  _hoisted_10
];
const _hoisted_12 = {
  key: 3,
  xmlns: "http://www.w3.org/2000/svg",
  height: "32px",
  viewBox: "0 0 24 24",
  width: "32px",
  fill: "#616161"
};
const _hoisted_13 = /* @__PURE__ */ createElementVNode("path", {
  d: "M0 0h24v24H0z",
  fill: "none"
}, null, -1);
const _hoisted_14 = /* @__PURE__ */ createElementVNode("path", { d: "M12 2C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm1 15h-2v-6h2v6zm0-8h-2V7h2v2z" }, null, -1);
const _hoisted_15 = [
  _hoisted_13,
  _hoisted_14
];
const _hoisted_16 = {
  key: 4,
  xmlns: "http://www.w3.org/2000/svg",
  height: "32px",
  viewBox: "0 0 24 24",
  width: "32px",
  fill: "#ffffff"
};
const _hoisted_17 = /* @__PURE__ */ createElementVNode("path", {
  d: "M0 0h24v24H0z",
  fill: "none"
}, null, -1);
const _hoisted_18 = /* @__PURE__ */ createElementVNode("path", { d: "M12 2C6.48 2 2 6.48 2 12s4.48 10 10 10 10-4.48 10-10S17.52 2 12 2zm1 15h-2v-6h2v6zm0-8h-2V7h2v2z" }, null, -1);
const _hoisted_19 = [
  _hoisted_17,
  _hoisted_18
];
function _sfc_render$1(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("span", _hoisted_1$1, [
    _ctx.type === "warning" ? (openBlock(), createElementBlock("svg", _hoisted_2$1, _hoisted_4$1)) : _ctx.type === "danger" ? (openBlock(), createElementBlock("svg", _hoisted_5$1, _hoisted_7)) : _ctx.type === "success" ? (openBlock(), createElementBlock("svg", _hoisted_8, _hoisted_11)) : _ctx.type === "default" ? (openBlock(), createElementBlock("svg", _hoisted_12, _hoisted_15)) : (openBlock(), createElementBlock("svg", _hoisted_16, _hoisted_19))
  ]);
}
var MIcon = /* @__PURE__ */ _export_sfc(_sfc_main$1, [["render", _sfc_render$1]]);
const _sfc_main = defineComponent({
  name: "MToast",
  components: {
    MIcon
  },
  props: {
    visible: Boolean,
    text: {
      type: String,
      default: ""
    },
    description: {
      type: String,
      default: ""
    },
    toastBackgroundColor: {
      type: String,
      default: ""
    },
    type: {
      type: String,
      default: "default"
    },
    onClose: {
      type: Function,
      default: () => null
    },
    onCloseHandler: {
      type: Function,
      required: true
    },
    offset: {
      type: Number,
      required: true
    },
    id: {
      type: Number,
      required: true
    },
    timeout: {
      type: Number,
      default: 5e3
    },
    position: {
      type: String,
      required: true
    },
    showCloseButton: {
      type: Boolean,
      default: true
    },
    swipeClose: {
      type: Boolean,
      default: true
    },
    hideProgressBar: {
      type: Boolean,
      default: false
    },
    showIcon: {
      type: Boolean,
      default: false
    },
    transition: {
      type: String,
      default: "bounce"
    }
  },
  setup(props, ctx) {
    const style = ref();
    const { width } = useScreenSize();
    const { swipedDiff, startSwipeHandler, swipeStyle, cleanUpMove } = useSwipe(props.position, props.onCloseHandler, props.swipeClose);
    const { transitionType } = useTransitionType(props.position, props.transition, swipedDiff);
    const { start, stop, progress } = useTimer(() => {
      props.onCloseHandler();
    }, props.timeout);
    const isSlotPassed = computed(() => ctx.slots.default);
    const isDescriptionHtml = computed(() => /<\/?[a-z][\s\S]*>/i.test(props.description));
    const startTimer = () => {
      if (props.timeout > 0) {
        start();
      }
    };
    const onMouseEnter = () => {
      if (props.timeout > 0 && width.value > 425) {
        stop();
      }
    };
    const onMouseLeave = () => {
      cleanUpMove("mousemove");
      startTimer();
    };
    const onMouseDown = (event) => {
      startSwipeHandler(event);
    };
    const onTouchStart = (event) => {
      startSwipeHandler(event);
    };
    watchEffect(() => {
      const { customStyle } = useCustomStyle(props.position, props.offset, props.toastBackgroundColor);
      style.value = customStyle.value;
    });
    onMounted(() => {
      startTimer();
    });
    return {
      style,
      transitionType,
      startTimer,
      progress,
      onTouchStart,
      onMouseLeave,
      onMouseDown,
      swipeStyle,
      isSlotPassed,
      isDescriptionHtml,
      onMouseEnter
    };
  }
});
const _hoisted_1 = { class: "mosha__toast__content-wrapper" };
const _hoisted_2 = { class: "mosha__toast__content" };
const _hoisted_3 = { class: "mosha__toast__content__text" };
const _hoisted_4 = ["innerHTML"];
const _hoisted_5 = {
  key: 1,
  class: "mosha__toast__content__description"
};
const _hoisted_6 = {
  key: 0,
  class: "mosha__toast__slot-wrapper"
};
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_MIcon = resolveComponent("MIcon");
  return openBlock(), createBlock(Transition, {
    name: _ctx.transitionType,
    type: "animation"
  }, {
    default: withCtx(() => [
      _ctx.visible ? (openBlock(), createElementBlock("div", {
        key: 0,
        class: normalizeClass(["mosha__toast", _ctx.toastBackgroundColor ? null : _ctx.type]),
        style: normalizeStyle([_ctx.style, _ctx.swipeStyle]),
        onMouseenter: _cache[1] || (_cache[1] = (...args) => _ctx.onMouseEnter && _ctx.onMouseEnter(...args)),
        onMouseleave: _cache[2] || (_cache[2] = (...args) => _ctx.onMouseLeave && _ctx.onMouseLeave(...args)),
        onTouchstartPassive: _cache[3] || (_cache[3] = (...args) => _ctx.onTouchStart && _ctx.onTouchStart(...args)),
        onMousedown: _cache[4] || (_cache[4] = (...args) => _ctx.onMouseDown && _ctx.onMouseDown(...args))
      }, [
        createElementVNode("div", _hoisted_1, [
          _ctx.showIcon ? (openBlock(), createBlock(_component_MIcon, {
            key: 0,
            type: _ctx.type
          }, null, 8, ["type"])) : createCommentVNode("", true),
          createElementVNode("div", _hoisted_2, [
            createElementVNode("div", _hoisted_3, toDisplayString(_ctx.text), 1),
            _ctx.description.length > 0 && _ctx.isDescriptionHtml ? (openBlock(), createElementBlock("div", {
              key: 0,
              class: "mosha__toast__content__description",
              innerHTML: _ctx.description
            }, null, 8, _hoisted_4)) : createCommentVNode("", true),
            _ctx.description.length > 0 && !_ctx.isDescriptionHtml ? (openBlock(), createElementBlock("div", _hoisted_5, toDisplayString(_ctx.description), 1)) : createCommentVNode("", true)
          ])
        ]),
        _ctx.isSlotPassed ? (openBlock(), createElementBlock("div", _hoisted_6, [
          renderSlot(_ctx.$slots, "default")
        ])) : createCommentVNode("", true),
        _ctx.showCloseButton ? (openBlock(), createElementBlock("div", {
          key: 1,
          class: "mosha__toast__close-icon",
          onClick: _cache[0] || (_cache[0] = (...args) => _ctx.onCloseHandler && _ctx.onCloseHandler(...args))
        })) : createCommentVNode("", true),
        !_ctx.hideProgressBar ? (openBlock(), createElementBlock("div", {
          key: 2,
          class: "mosha__toast__progress",
          style: normalizeStyle({ width: `${_ctx.progress}%` })
        }, null, 4)) : createCommentVNode("", true)
      ], 38)) : createCommentVNode("", true)
    ]),
    _: 3
  }, 8, ["name"]);
}
var Toast = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render]]);
const toasts = {
  "top-left": [],
  "top-right": [],
  "bottom-left": [],
  "bottom-right": [],
  "top-center": [],
  "bottom-center": []
};
let toastId = 0;
const createToast = (content, options) => {
  const id = toastId++;
  const initializedOptions = options ? initializeOptions(options) : DEFAULT_OPTIONS;
  if (content.__v_isVNode) {
    setupVNode(id, ToastContentType.VNODE, initializedOptions, content);
    return {
      close: () => close(id, initializedOptions.position)
    };
  }
  if (content.hasOwnProperty("render")) {
    setupVNode(id, ToastContentType.COMPONENT, initializedOptions, content);
    return {
      close: () => close(id, initializedOptions.position)
    };
  }
  const initializedContent = initializeContent(content);
  setupVNode(id, ToastContentType.TITLE_DESCRIPTION, initializedOptions, initializedContent);
  return {
    close: () => close(id, initializedOptions.position)
  };
};
const setupVNode = (id, contentType, options, content) => {
  setTimeout(() => {
    const verticalOffset = moveToastsOnAdd(options, toasts, TOAST_GAP);
    const container = document.createElement("div");
    document.body.appendChild(container);
    let toastVNode = void 0;
    if (contentType === ToastContentType.VNODE) {
      toastVNode = createVNode(Toast, setupVNodeProps(options, id, verticalOffset, close), () => [content]);
    } else if (contentType === ToastContentType.TITLE_DESCRIPTION) {
      toastVNode = createVNode(Toast, setupVNodeProps(options, id, verticalOffset, close, content));
    } else {
      toastVNode = createVNode(Toast, setupVNodeProps(options, id, verticalOffset, close), () => [createVNode(content)]);
    }
    render(toastVNode, container);
    toasts[options.position].push({ toastVNode, container });
    if (toastVNode.component) {
      toastVNode.component.props.visible = true;
    }
  }, 1);
};
const setupVNodeProps = (options, id, offset, closeFn, content) => {
  return {
    ...options,
    ...content,
    id,
    offset,
    visible: false,
    onCloseHandler: () => {
      closeFn(id, options.position ? options.position : "top-right");
    }
  };
};
const initializeOptions = (options) => {
  const processedOptions = {
    ...options,
    type: options.type || DEFAULT_OPTIONS.type,
    timeout: options.timeout || DEFAULT_OPTIONS.timeout,
    showCloseButton: options.showCloseButton,
    position: options.position || DEFAULT_OPTIONS.position,
    showIcon: options.showIcon,
    swipeClose: options.swipeClose,
    transition: options.transition || DEFAULT_OPTIONS.transition
  };
  processedOptions.hideProgressBar = processedOptions.timeout !== void 0 && processedOptions.timeout <= 0;
  if (options.hideProgressBar !== void 0) {
    processedOptions.hideProgressBar = options.hideProgressBar;
  }
  return processedOptions;
};
const initializeContent = (content) => {
  const text = typeof content === "string" ? content : content.title;
  const description = typeof content === "string" ? void 0 : content.description;
  return { text, description };
};
const moveToastsOnAdd = (options, toasts2, toastGap) => {
  let verticalOffset = toastGap;
  if (!options.position)
    throw new Error("no position");
  toasts2[options.position].forEach(({ toastVNode }) => {
    const offsetHeight = toastVNode.el.offsetHeight + toastGap;
    verticalOffset += offsetHeight || 0;
  });
  return verticalOffset;
};
const moveToastsOnClose = (index2, toastArr, position, toastHeight) => {
  for (let i = index2; i < toastArr.length; i++) {
    const { toastVNode } = toastArr[i];
    if (!toastVNode.el)
      return;
    const verticalPos = position.split("-")[0] || "top";
    const pos = parseInt(toastVNode.el.style[verticalPos], 10) - toastHeight - TOAST_GAP;
    if (!toastVNode.component)
      return;
    toastVNode.component.props.offset = pos;
  }
};
const close = (id, position) => {
  const toastArr = toasts[position];
  const index2 = toastArr.findIndex(({ toastVNode: toastVNode2 }) => toastVNode2.props && id === toastVNode2.props.id);
  if (index2 === -1)
    return;
  const { container, toastVNode } = toastArr[index2];
  if (!toastVNode.el)
    return;
  const height = toastVNode.el.offsetHeight;
  toasts[position].splice(index2, 1);
  moveToastsOnClose(index2, toastArr, position, height);
  if (!toastVNode.component)
    return;
  toastVNode.component.props.visible = false;
  if (toastVNode.component.props.onClose) {
    toastVNode.component.props.onClose();
  }
  setTimeout(() => {
    render(null, container);
    document.body.removeChild(container);
  }, 1e3);
};
const clearToasts = () => {
  Object.entries(toasts).forEach(([key, val]) => {
    if (val.length > 0) {
      const ids = val.map((toast) => {
        return toast.toastVNode.props.id;
      });
      ids.forEach((id) => {
        close(id, key);
      });
    }
  });
};
var index = /* @__PURE__ */ (() => '@charset "UTF-8";.mosha__toast{touch-action:none;display:flex;justify-content:space-between;position:fixed;min-height:64px;max-height:800px;box-sizing:border-box;overflow:hidden;padding:12px 8px;word-break:break-word;min-width:312px;max-width:480px;z-index:9999;width:-webkit-max-content;width:-moz-max-content;width:max-content;transition:top .3s ease-out .5s,bottom .3s ease-out .5s;border-radius:8px;box-shadow:0 1px 10px #0000001a,0 2px 15px #0000000d;margin:0 16px;-webkit-touch-callout:none;-webkit-user-select:none;-moz-user-select:none;user-select:none}.mosha__toast__content-wrapper{display:flex;align-items:center}.mosha__toast__content{font-family:sans-serif;line-height:20px;display:flex;flex-direction:column;color:#fff}.mosha__toast__content__text{margin-bottom:2px;font-size:16px;font-weight:700}.mosha__toast__content__description{font-size:14px;font-weight:400}.mosha__toast__slot-wrapper{width:100%}.mosha__toast__close-icon:before{font-size:20px;cursor:pointer;content:"\\d7";color:#fff;transition:color .3s;font-weight:600;margin-left:10px;position:relative;top:-12px}.mosha__toast__close-icon:hover:before{color:gray}.mosha__toast__progress{transition:all linear .2s;position:absolute;z-index:9999;height:8px;background-color:#fff9;bottom:0;margin-left:-8px}.mosha__toast.success{background-color:#06d6a0}.mosha__toast.warning{background-color:#ffc43d}.mosha__toast.info{background-color:#1b9aaa}.mosha__toast.danger{background-color:#ef476f}.mosha__toast.default{background-color:#fff}.mosha__toast.default .mosha__toast__content{color:#616161}.mosha__toast.default .mosha__toast__close-icon:before{color:#616161}.mosha__toast.default .mosha__toast__close-icon:hover:before{color:#d0d4d4}.mosha__toast.default .mosha__toast__progress{background-image:linear-gradient(-225deg,#69EACB 0%,#EACCF8 48%,#6654F1 100%)}@media only screen and (max-width: 475px){.mosha__toast{max-width:95.2%;left:0;right:0;margin:0 auto}}.mosha__icon{margin-right:16px}.mosha__bounceInRight-enter-active{-webkit-animation:bounceInRight .7s;animation:bounceInRight .7s}.mosha__bounceInRight-leave-active{-webkit-animation:bounceOutLeft .7s;animation:bounceOutLeft .7s}.mosha__bounceInLeft-enter-active{-webkit-animation:bounceInLeft .7s;animation:bounceInLeft .7s}.mosha__bounceInLeft-leave-active{-webkit-animation:bounceOutRight .7s;animation:bounceOutRight .7s}.mosha__bounceInDown-enter-active{-webkit-animation:bounceInDown .7s;animation:bounceInDown .7s}.mosha__bounceInDown-leave-active{-webkit-animation:bounceOutUp .7s;animation:bounceOutUp .7s}.mosha__bounceInUp-enter-active{-webkit-animation:bounceInUp .7s;animation:bounceInUp .7s}.mosha__bounceInUp-leave-active{-webkit-animation:bounceOutDown .7s;animation:bounceOutDown .7s}@-webkit-keyframes bounceInRight{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;transform:translate3d(2000px,0,0)}60%{opacity:1;transform:translate3d(-25px,0,0)}75%{transform:translate3d(10px,0,0)}90%{transform:translate3d(-5px,0,0)}to{transform:none}}@keyframes bounceInRight{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;transform:translate3d(2000px,0,0)}60%{opacity:1;transform:translate3d(-25px,0,0)}75%{transform:translate3d(10px,0,0)}90%{transform:translate3d(-5px,0,0)}to{transform:none}}@-webkit-keyframes bounceOutLeft{20%{opacity:1;transform:translate3d(-20px,0,0)}to{opacity:0;transform:translate3d(2000px,0,0)}}@keyframes bounceOutLeft{20%{opacity:1;transform:translate3d(-20px,0,0)}to{opacity:0;transform:translate3d(2000px,0,0)}}@-webkit-keyframes bounceInLeft{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;transform:translate3d(-2000px,0,0)}60%{opacity:1;transform:translate3d(25px,0,0)}75%{transform:translate3d(-10px,0,0)}90%{transform:translate3d(5px,0,0)}to{transform:none}}@keyframes bounceInLeft{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;transform:translate3d(-2000px,0,0)}60%{opacity:1;transform:translate3d(25px,0,0)}75%{transform:translate3d(-10px,0,0)}90%{transform:translate3d(5px,0,0)}to{transform:none}}@-webkit-keyframes bounceOutRight{20%{opacity:1;transform:translate3d(20px,0,0)}to{opacity:0;transform:translate3d(-2000px,0,0)}}@keyframes bounceOutRight{20%{opacity:1;transform:translate3d(20px,0,0)}to{opacity:0;transform:translate3d(-2000px,0,0)}}@-webkit-keyframes bounceInUp{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;transform:translate3d(0,3000px,0)}60%{opacity:1;transform:translate3d(0,-20px,0)}75%{transform:translate3d(0,10px,0)}90%{transform:translate3d(0,-5px,0)}to{transform:translateZ(0)}}@keyframes bounceInUp{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;transform:translate3d(0,3000px,0)}60%{opacity:1;transform:translate3d(0,-20px,0)}75%{transform:translate3d(0,10px,0)}90%{transform:translate3d(0,-5px,0)}to{transform:translateZ(0)}}@-webkit-keyframes bounceOutUp{20%{transform:translate3d(0,-10px,0)}40%,45%{opacity:1;transform:translate3d(0,20px,0)}to{opacity:0;transform:translate3d(0,-2000px,0)}}@keyframes bounceOutUp{20%{transform:translate3d(0,-10px,0)}40%,45%{opacity:1;transform:translate3d(0,20px,0)}to{opacity:0;transform:translate3d(0,-2000px,0)}}@-webkit-keyframes bounceInDown{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;transform:translate3d(0,-3000px,0)}60%{opacity:1;transform:translate3d(0,25px,0)}75%{transform:translate3d(0,-10px,0)}90%{transform:translate3d(0,5px,0)}to{transform:none}}@keyframes bounceInDown{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;transform:translate3d(0,-3000px,0)}60%{opacity:1;transform:translate3d(0,25px,0)}75%{transform:translate3d(0,-10px,0)}90%{transform:translate3d(0,5px,0)}to{transform:none}}@-webkit-keyframes bounceOutDown{20%{transform:translate3d(0,10px,0)}40%,45%{opacity:1;transform:translate3d(0,-20px,0)}to{opacity:0;transform:translate3d(0,2000px,0)}}@keyframes bounceOutDown{20%{transform:translate3d(0,10px,0)}40%,45%{opacity:1;transform:translate3d(0,-20px,0)}to{opacity:0;transform:translate3d(0,2000px,0)}}.mosha__slideInRight-enter-active{-webkit-animation:slideInRight .5s;animation:slideInRight .5s}.mosha__slideInRight-leave-active{-webkit-animation:slideOutRight .5s;animation:slideOutRight .5s}.mosha__slideInLeft-enter-active{-webkit-animation:slideInLeft .5s;animation:slideInLeft .5s}.mosha__slideInLeft-leave-active{-webkit-animation:slideOutLeft .5s;animation:slideOutLeft .5s}.mosha__slideInDown-enter-active{-webkit-animation:slideInDown .5s;animation:slideInDown .5s}.mosha__slideInDown-leave-active{-webkit-animation:slideOutUp .5s;animation:slideOutUp .5s}.mosha__slideInUp-enter-active{-webkit-animation:slideInUp .5s;animation:slideInUp .5s}.mosha__slideInUp-leave-active{-webkit-animation:slideOutDown .5s;animation:slideOutDown .5s}@-webkit-keyframes slideInRight{0%{transform:translate3d(110%,0,0);visibility:visible}to{transform:translateZ(0)}}@keyframes slideInRight{0%{transform:translate3d(110%,0,0);visibility:visible}to{transform:translateZ(0)}}@-webkit-keyframes slideOutLeft{0%{transform:translateZ(0)}to{visibility:hidden;transform:translate3d(-110%,0,0)}}@keyframes slideOutLeft{0%{transform:translateZ(0)}to{visibility:hidden;transform:translate3d(-110%,0,0)}}@-webkit-keyframes slideInLeft{0%{transform:translate3d(-110%,0,0);visibility:visible}to{transform:translateZ(0)}}@keyframes slideInLeft{0%{transform:translate3d(-110%,0,0);visibility:visible}to{transform:translateZ(0)}}@-webkit-keyframes slideOutRight{0%{transform:translateZ(0)}to{visibility:hidden;transform:translate3d(110%,0,0)}}@keyframes slideOutRight{0%{transform:translateZ(0)}to{visibility:hidden;transform:translate3d(110%,0,0)}}@-webkit-keyframes slideInUp{0%{transform:translate3d(0,110%,0);visibility:visible}to{transform:translateZ(0)}}@keyframes slideInUp{0%{transform:translate3d(0,110%,0);visibility:visible}to{transform:translateZ(0)}}@-webkit-keyframes slideInDown{0%{opacity:0;transform:translate3d(0,-120%,0)}to{opacity:1;transform:translateZ(0)}}@keyframes slideInDown{0%{opacity:0;transform:translate3d(0,-120%,0)}to{opacity:1;transform:translateZ(0)}}@-webkit-keyframes slideOutDown{0%{transform:translateZ(0)}to{visibility:hidden;transform:translate3d(0,500px,0)}}@keyframes slideOutDown{0%{transform:translateZ(0)}to{visibility:hidden;transform:translate3d(0,500px,0)}}@-webkit-keyframes slideOutUp{0%{transform:translateZ(0)}to{visibility:hidden;transform:translate3d(0,-500px,0)}}@keyframes slideOutUp{0%{transform:translateZ(0)}to{visibility:hidden;transform:translate3d(0,-500px,0)}}.mosha__zoomIn-enter-active{-webkit-animation:zoomIn .5s;animation:zoomIn .5s}.mosha__zoomIn-leave-active{-webkit-animation:zoomOut .5s;animation:zoomOut .5s}@-webkit-keyframes zoomIn{0%{opacity:0;transform:scale3d(.3,.3,.3)}50%{opacity:1}}@keyframes zoomIn{0%{opacity:0;transform:scale3d(.3,.3,.3)}50%{opacity:1}}@-webkit-keyframes zoomOut{0%{opacity:1}50%{opacity:0;transform:scale3d(.3,.3,.3)}to{opacity:0}}@keyframes zoomOut{0%{opacity:1}50%{opacity:0;transform:scale3d(.3,.3,.3)}to{opacity:0}}.mosha__fadeOutRight-leave-active{-webkit-animation:fadeOutRight .5s;animation:fadeOutRight .5s}.mosha__fadeOutLeft-leave-active{-webkit-animation:fadeOutLeft .5s;animation:fadeOutLeft .5s}@-webkit-keyframes fadeOutLeft{0%{opacity:1}to{opacity:0;transform:translate3d(-100%,0,0)}}@keyframes fadeOutLeft{0%{opacity:1}to{opacity:0;transform:translate3d(-100%,0,0)}}@-webkit-keyframes fadeOutRight{0%{opacity:1}to{opacity:0;transform:translate3d(100%,0,0)}}@keyframes fadeOutRight{0%{opacity:1}to{opacity:0;transform:translate3d(100%,0,0)}}\n')();
var main = {
  install: (app) => {
    app.config.globalProperties.$moshaToast = createToast;
    app.provide("moshaToast", createToast);
  }
};
export { ToastContentType, clearToasts, createToast, main as default, withProps };
